function [A b] = axb(e,x)
%A * x = b
% Compute matrix A and vector b from symbolic equation 'e' (e = 0)
% eq - [N x 1] vector of symbolic equations
% x - [N x 1] vector of symbolic variables
%
% A - [N x N] matrix
% b - [N x 1] vector
%
% Ex.:
% syms a b c
% eq = [5*a + 6*b + 3; 5*a; 9*c + 6];
% [AA bb] = axb(eq,[a;b;c]);
%
% Author: Vladimir Petrik, vladko.petrik@gmail.com
% Modification: Pavel Krsek, krsek@cmp.felk.cvut.cz

    N = length(e);
    A = sym(zeros(N,N)); %preallocation
    b = sym(zeros(N,1));
    
    for i = 1:N %for each equation
        
        %find A
        C = expand(e(i));
        for j = 1:N
            [C T] = coeffs(C(1),x(j));
            ind = find(eq(T,x(j)), 1);
            if(isempty(ind))
                A(i,j) = 0;
            else
                A(i,j) = C(ind);
            end;
         end;

        %find b
        ind = find(eq(T,1), 1);
        if(isempty(ind))
            b(i) = 0;
        else
            b(i) = -C(ind);
        end;
 
    end;

